@@ -54,7 +54,6 @@ html_engine_edit_selection_updater_new (HTMLEngine *engine)
 
 	new = g_new (HTMLEngineEditSelectionUpdater, 1);
 
-	gtk_object_ref (GTK_OBJECT (engine));
 	new->engine  = engine;
 	new->idle_id = 0;
 
@@ -75,7 +74,6 @@ html_engine_edit_selection_updater_destroy (HTMLEngineEditSelectionUpdater *upda
 	if (updater->idle_id != 0)
 		gtk_idle_remove (updater->idle_id);
 
-	gtk_object_unref (GTK_OBJECT (updater->engine));
 	g_free (updater);
 }
 
@@ -91,8 +89,12 @@ updater_idle_callback (gpointer data)
 
 	if (engine->mark && html_cursor_get_position (engine->mark) != html_cursor_get_position (engine->cursor))
 		html_engine_select_interval (engine, html_interval_new_from_cursor (engine->mark, engine->cursor));
-	else
+	else {
+		gboolean selection_mode = engine->selection_mode;
+
 		html_engine_disable_selection (engine);
+		engine->selection_mode = selection_mode;
+	}
 
 	updater->idle_id = 0;
 	return FALSE;
